/*****************************************************
 * int islzw (char *name, char *mapset);             *
 * Checks that lzw_compression_bits between 9 and 20 *
 * If so, file is lzw_compressed.                    *
 * ------------------------------------------------- *
 * int setlzwbits (char *name, char *mapset,         *
 *                 RASTER_MAP_TYPE maptype);         *
 * Sets the lzw_compression_bits field to -1         *
 ****************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <fcntl.h>
#include "gis.h"
#include "local_proto.h"

#define FORMAT_FILE "f_format"

int islzw (char *name, char *mapset)
{
    int value, in_stat;
    char element[100], path[1024], *thestr, *ss;
    struct Key_Value *format_keys;
    
    sprintf (element, "cell_misc/%s", name);

    G__file_name (path, element, FORMAT_FILE, mapset);
    format_keys = G_read_key_value_file (path, &in_stat);
    if (in_stat != 0)
    {
        G_warning ("Unable to open format file %s", path);
        return 0;
    }
 
    thestr = G_find_key_value ("lzw_compression_bits", format_keys);
    if (thestr == NULL)
    {
        G_free (format_keys);
        G_warning ("Unable to find lzw_compression_bits in %s", path);
        return 0;
    }
    
    value = (int) strtol (thestr, &ss, 10);
    if (ss == thestr)
    {
        G_free (format_keys);
        G_warning ("No lzw_compression_bits value in %s", path);
        return 0;
    }

    G_free (format_keys);
    /* Only 9-20 should be valid, but some old rasters may have 0,
     * Our token is -1 for a converted raster
     */
    return (value != -1);    
}

int setlzwbits (char *name, char *mapset, RASTER_MAP_TYPE maptype)
{
    int in_stat = 0;
    char element[100], path[1024];
    struct Key_Value *format_keys;
    
    format_keys = G_create_key_value();

    if (maptype == FCELL_TYPE)
        G_set_key_value ("type", "float", format_keys);
    else
        G_set_key_value ("type", "double", format_keys);

    G_set_key_value ("byte_order", "xdr", format_keys);
    G_set_key_value ("lzw_compression_bits", "-1", format_keys);

    sprintf (element, "cell_misc/%s", name);
    G__file_name (path, element, FORMAT_FILE, mapset);
    unlink (path);
    G__make_mapset_element (element);
    G_write_key_value_file (path, format_keys, &in_stat);

    G_free (format_keys);
    return in_stat;
}
 
/* vim: set softtabstop=4 shiftwidth=4 expandtab: */
